All Subtitle Options for mencoder

Code
      -sub <subtitlefile1,subtitlefile2,...>
              Use/display  these  subtitle  files.   Only one file can be displayed at the same time.

       -sub-bg-alpha <0-255>
              Specify the alpha channel value  for  subtitles  and  OSD  backgrounds.  Big values mean more transparency.  0 means completely
              transparent.

       -sub-bg-color <0-255>
              Specify the color value for subtitles and OSD backgrounds.  Currently  subtitles  are  grayscale so this value is equivalent to
              the intensity of the color.  255 means white and 0 black.

       -sub-demuxer <[+]name> (-subfile only) (BETA CODE)
              Force subtitle demuxer type for -subfile.  Use a + before  the
              name  to force it, this will skip some checks!  Give the demuxer
              name as printed by -sub-demuxer help.  For backward compatibility it also accepts the demuxer ID as defined in subreader.h.

       -sub-fuzziness <mode>
              Adjust matching fuzziness when searching for subtitles:
                 0    exact match
                 1    Load all subs containing movie name.
                 2    Load all subs in the current directory.

       -sub-no-text-pp
              Disables any kind of text post processing done after loading the
              subtitles.  Used for debug purposes.

       -subalign <0-2>
              Specify which edge of the subtitles should  be  aligned  at  the
              height given by -subpos.
                 0    Align subtitle top edge (original behavior).
                 1    Align subtitle center.
                 2    Align subtitle bottom edge (default).

       -subcc
              Display  DVD  Closed  Caption (CC) subtitles.  These are not the
              VOB subtitles, these are special ASCII subtitles for the hearing
              impaired  encoded  in  the  VOB userdata stream on most region 1
              DVDs.  CC subtitles have not been spotted on DVDs from other regions so far.

       -subcp <codepage> (iconv only)
              If  your  system  supports  iconv(3), you can use this option to
              specify the subtitle codepage.

              EXAMPLE:
                 -subcp latin2
                 -subcp cp1250

       -subcp enca:<language>:<fallback codepage> (ENCA only)
              You can specify your language using a two letter  language  code
              to  make ENCA detect the codepage automatically.  If unsure, enter anything and watch mplayer  -v  output  for  available  languages.   Fallback  codepage specifies the codepage to use, when
              autodetection fails.

              EXAMPLE:
                 -subcp enca:cs:latin2
                      Guess the encoding, assuming the  subtitles  are  Czech,
                      fall back on latin 2, if the detection fails.
                 -subcp enca:pl:cp1250
                      Guess the encoding for Polish, fall back on cp1250.

       -subdelay <sec>
              Delays subtitles by <sec> seconds.  Can be negative.

       -subfile <filename> (BETA CODE)
              Currently useless.  Same as -audiofile, but for subtitle streams
              (OggDS?).

       -subfont <path to font (FreeType), font pattern (Fontconfig)> (FreeType
       only)
              Sets the subtitle font (see -font).  If no  -subfont  is  given,
              -font is used.

       -subfont-autoscale <0-3> (FreeType only)
              Sets the autoscale mode.
              NOTE:  0 means that text scale and OSD scale are font heights in
              points.

              The mode can be:

                 0    no autoscale
                 1    proportional to movie height
                 2    proportional to movie width
                 3    proportional to movie diagonal (default)

       -subfont-blur <0-8> (FreeType only)
              Sets the font blur radius (default: 2).

       -subfont-encoding <value> (FreeType only)
              Sets the font encoding.  When set to unicode, all  the  glyphs
              from  the  font  file  will be rendered and unicode will be used
              (default: unicode).

       -subfont-osd-scale <0-100> (FreeType only)
              Sets the autoscale coefficient of the OSD elements (default: 6).

       -subfont-outline <0-8> (FreeType only)
              Sets the font outline thickness (default: 2).

       -subfont-text-scale <0-100> (FreeType only)
              Sets  the  subtitle  text autoscale coefficient as percentage of
              the screen size (default: 5).

       -subfps <rate>
              Specify the framerate of the subtitle file (default: movie fps).
              NOTE: <rate> > movie fps speeds the subtitles up for frame-based
              subtitle files and slows them down for time-based ones.

       -subpos <0-100> (useful with -vf expand)
              Specify the position of subtitles on the screen.  The  value  is
              the vertical position of the subtitle in % of the screen height.

       -subwidth <10-100>
              Specify the maximum width of subtitles on  the  screen.   Useful
              for  TV-out.  The value is the width of the subtitle in % of the
              screen width.



Source: http://www.mplayerhq.hu/DOCS/man/en/mplayer.1.txt


Russ Tanner, Founder, Administrator, Programmer
GlobalSkywatch.com
My Chemtrail Story